@@ -56,7 +56,7 @@ else:
     cached_property = lambda x: property(functools.lru_cache(maxsize=None)(x))  # noqa: E731
 
 
-__version__ = '0.9.0'
+__version__ = '0.10.0'
 
 
 class _depstr:
@@ -275,6 +275,11 @@ class _WheelBuilder():
                 # latter specifies the target macOS version Python was built
                 # against.
                 parts[1] = platform.mac_ver()[0]
+                if parts[1] >= '11':
+                    # Only pick up the major version, which changed from 10.X
+                    # to X.0 from macOS 11 onwards. See
+                    # https://github.com/FFY00/meson-python/issues/160
+                    parts[1] = parts[1].split('.')[0]
 
             if parts[1] in ('11', '12'):
                 # Workaround for bug where pypa/packaging does not consider macOS
